% Since empirical kinetic data was not collected for the glucose transport of our device, 
% and because at 10% glucose level the polyermization reaction seems to reach its plateau,
% we will assume with functional glucose transport circuit, the glucose concentration will 
% be at least the same across cell membrane. And the reaction velocity determined from 
% the glgC assay will be a lower limit. 

% Vmax=0.00111 and Km=0.265

sbioloadproject('insulindemo', 'm1');
warnSettings = warning('off', 'SimBiology:DimAnalysisNotDone_MatlabFcn_Dimensionless');

mealDose = sbioselect(m1, 'Name', 'Single Meal');
get(mealDose);


%% Make the dosing model as influenced by our device
% first solve the two odes to see what are the changes in 
[T1,Y1] = ode45(@glu_gut,[0 2],[433 0]) ;%;
[T2,Y2] = ode45(@glu_gut1,[2 3],[Y1(end,1) Y1(end,2)]) ;%;

subplot(2,1,1)
plot(T1,Y1(1:end,1));
title('Decrease of glucose amount over time')
subplot(2,1,2)
plot(T1,Y1(1:end,2));
title('Production of glycogen amount over time')
%%
d1 = sbiodose('d1','schedule');
d1.Amount = [Y1(end,1)*0.18, (78-Y1(end,1)*0.18)/2, (78-Y1(end,1)*0.18)/2];
d1.AmountUnits = 'gram';
d1.TargetName = 'Dose';
d1.Time=[0 2 2.5];
d1.TimeUnits = 'hour';
d1.Active = true;

%%
configset = getconfigset(m1,'active');
configset.StopTime = 7;
normalMealSim = sbiosimulate(m1, configset, [], mealDose);

diabeticVar = sbioselect(m1, 'Name', 'Type 2 diabetic');
diabeticMealSim = sbiosimulate(m1, configset, diabeticVar, mealDose);

outputNames = {'Plasma Glu Conc', 'Plasma Ins Conc', 'Glu Prod', ...
    'Glu Appear Rate', 'Glu Util', 'Ins Secr'};

figure(1);

for i = 1:numel(outputNames)
    subplot(2, 3, i);

    [tNormal, yNormal  ]  = normalMealSim.selectbyname(outputNames{i});
    [tDiabetic, yDiabetic]  = diabeticMealSim.selectbyname(outputNames{i});

    plot( tNormal    , yNormal   , '-'       , ...
          tDiabetic  , yDiabetic , '--'      );

    % Annotate figures
    outputParam = sbioselect(m1, 'Name', outputNames{i});
    title(outputNames{i});
    xlabel('time (hour)');
    if strcmp(outputParam.Type, 'parameter')
        ylabel(outputParam.ValueUnits);
    else
        ylabel(outputParam.InitialAmountUnits);
    end
    xlim([0 7]);

    % Add legend
    if i == 3
        legend({'Normal', 'Diabetic'}, 'Location', 'Best');
    end

end
%%
configset = getconfigset(m1,'active');
configset.StopTime = 7;
normalMealSim = sbiosimulate(m1, configset, [], d1);

diabeticVar = sbioselect(m1, 'Name', 'Type 2 diabetic');
diabeticMealSim = sbiosimulate(m1, configset, diabeticVar, d1);

outputNames = {'Plasma Glu Conc', 'Plasma Ins Conc', 'Glu Prod', ...
    'Glu Appear Rate', 'Glu Util', 'Ins Secr'};

figure(2);

for i = 1:numel(outputNames)
    subplot(2, 3, i);

    [tNormal, yNormal  ]  = normalMealSim.selectbyname(outputNames{i});
    [tDiabetic, yDiabetic]  = diabeticMealSim.selectbyname(outputNames{i});

    plot( tNormal    , yNormal   , '-'       , ...
          tDiabetic  , yDiabetic , '--'      );

    % Annotate figures
    outputParam = sbioselect(m1, 'Name', outputNames{i});
    title(outputNames{i});
    xlabel('time (hour)');
    if strcmp(outputParam.Type, 'parameter')
        ylabel(outputParam.ValueUnits);
    else
        ylabel(outputParam.InitialAmountUnits);
    end
    xlim([0 7]);

    % Add legend
    if i == 3
        legend({'Normal', 'Diabetic'}, 'Location', 'Best');
    end

end